try:
    from ._version import __version__
except ImportError:
    # Fallback when using the package in dev mode without installing
    # in editable mode with pip. It is highly recommended to install
    # the package from a stable release or in editable mode: https://pip.pypa.io/en/stable/topics/local-project-installs/#editable-installs
    import warnings

    warnings.warn(
        "Importing 'amzn_sagemaker_aiops_jupyterlab_extension' outside a proper installation."
    )
    __version__ = "dev"
import json
from os import path
from pathlib import Path
from .handlers import register_handlers
from aws_embedded_metrics.config import get_config


# Path to the frontend JupyterLab extension assets
def _jupyter_labextension_paths():
    HERE = Path(__file__).parent.resolve()

    with (HERE / "labextension" / "package.json").open(encoding="utf-8") as fid:
        package_json = json.load(fid)

    return [{"src": "labextension", "dest": package_json["name"]}]


def _jupyter_server_extension_points():
    return [
        {
            "module": "amzn_sagemaker_aiops_jupyterlab_extension",
        }
    ]


# Entrypoint of the server extension
def _load_jupyter_server_extension(nb_app):
    nb_app.log.info(f"Loading SageMaker JupyterLab server extension {__version__}")

    # configure EMF logger
    emf_config = get_config()
    emf_config.namespace = "StudioAIOpsJupyterLabExtensionServer"

    register_handlers(nb_app)


load_jupyter_server_extension = _load_jupyter_server_extension



# Common Constants
LOGFILE_ENV_NAME = "SAGEMAKER_AIOPS_LOG_FILE"
SCHEMAS_DIR = "schemas/"

# Jupyter Server constants for Log files and schema
SERVER_LOG_FILE_NAME = "sm-aiops-jupyter-server-ext.log"
API_LOG_FILE_NAME = "sm-aiops-jupyter-server-ext.api.log"
REQUEST_LOG_FILE_NAME = "sm-aiops-jupyter-server-ext.requestss.log"
SERVER_LOG_SCHEMA = "http://sagemaker.studio.jupyterserver.log.schema"
HANDLER_METRICS_SCHEMA = "http://sagemaker.studio.jupyterserver.api.metric.schema"
REQUEST_METRICS_SCHEMA = (
    "http://sagemaker.studio.jupyterserver.httprequest.metric.schema"
)

# JupyterLab constants for Log files and schema
JUPYTERLAB_OPERATION_LOG_FILE_NAME = "sm-aiops-jupyterlab-ext.ui.log"
JUPYTERLAB_METRICS_LOG_FILE_NAME = "sm-aiops-jupyterlab-ext.ui.metrics.log"
JUPYTERLAB_OPERATIONAL_LOG_SCHEMA = "http://sagemaker.studio.jupyterlab.ui.log.schema"
JUPYTERLAB_PERFORMANCE_METRICS_LOG_SCHEMA = (
    "http://sagemaker.studio.jupyterlab.ui.performance.schema"
)

CONTEXT_INJECT_PLACEHOLDER = "__INJECT__"
DEFAULT_HOME_DIRECTORY = "/home/sagemaker-user"



import logging
import os
from functools import lru_cache

from botocore.session import Session
from amzn_sagemaker_aiops_jupyterlab_extension.utils.file_watcher import (
    WatchedJsonFile,
)

SAGEMAKER_INTERNAL_METADATA_FILE_PATH = "/opt/.sagemakerinternal/internal-metadata.json"
METADATA_FILE_PATH = os.environ.get(
    "RESOURCE_METADATA_FILE", "/opt/ml/metadata/resource-metadata.json"
)
METADATA_DIR = os.environ.get("METADATA_DIR", "/opt/.sagemakerinternal")

_watched_resource_metadata_file = WatchedJsonFile(METADATA_FILE_PATH, logging)
_watched_internal_metadata_file = WatchedJsonFile(
    SAGEMAKER_INTERNAL_METADATA_FILE_PATH, logging
)


@lru_cache(maxsize=1)
def get_region_name():
    region = os.environ.get("AWS_REGION")
    if region is not None:
        return region
    else:
        return get_default_aws_region()


@lru_cache(maxsize=1)
def get_default_aws_region():
    return os.environ.get("AWS_DEFAULT_REGION", "us-west-2")


@lru_cache(maxsize=1)
def get_aws_account_id():
    return os.environ.get("AWS_ACCOUNT_ID", "MISSING_AWS_ACCOUNT_ID")


@lru_cache(maxsize=1)
def get_domain_id():
    return _watched_resource_metadata_file.get_key("DomainId", "MISSING_DOMAIN_ID")


@lru_cache(maxsize=1)
def get_user_profile_name():
    return _watched_resource_metadata_file.get_key(
        "UserProfileName", "MISSING_DOMAIN_ID"
    )


@lru_cache(maxsize=1)
def get_stage():
    return _watched_internal_metadata_file.get_key("Stage")


def get_partition():
    return Session().get_partition_for_region(get_region_name())


@lru_cache(maxsize=1)
def get_space_name():
    return _watched_resource_metadata_file.get_key("SpaceName", "MISSING_SPACE_NAME")
